<?xml version="1.0" ?>

<!--Description:

 Converts an XLIFF document to a TMX one.

Usage:

 C:\>msxsl <input> XLIFFToTMX.xsl Src=<srccode> Trg=<trgcode> > <output>
 Where <input> is the XLIFF document to convert, <srccode> and <trgcode> are the ISO
 locale codes for the source and target languages, and <output> is the result file.

Example:

 C:\>msxsl Input1.xlf XLIFFToTMX.xsl Src=en-US Trg=ja-JP > TheTM.tmx

Notes:

 The TMX file generated is TMX 1.3.

-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 version="1.0">

 <xsl:output method="xml" encoding="utf-8" indent="yes"/>
 <xsl:param name="Src">en-US</xsl:param>
 <xsl:param name="Trg"></xsl:param>

 <xsl:template match="text()"/>

 <xsl:template match="xliff">
  <tmx version="1.3">
   <xsl:element name="header">
    <xsl:attribute name="creationtool">TMXFromXLIFF</xsl:attribute>
    <xsl:attribute name="creationtoolversion">1.0</xsl:attribute>
    <xsl:attribute name="segtype">paragraph</xsl:attribute>
    <xsl:attribute name="o-tmf">xliff-doc</xsl:attribute>
    <xsl:attribute name="datatype">plaintext</xsl:attribute>
    <xsl:attribute name="srclang"><xsl:value-of select="$Src"/></xsl:attribute>
    <xsl:attribute name="adminlang">en</xsl:attribute>
   </xsl:element>
   <body>
    <xsl:apply-templates/>
   </body>
  </tmx>
 </xsl:template>

 <xsl:template match="//trans-unit">
   <xsl:element name="tu">
    <xsl:attribute name="tuid"><xsl:value-of select="@id"/></xsl:attribute>
    <xsl:element name="tuv">
     <xsl:attribute name="xml:lang"><xsl:value-of select="$Src"/></xsl:attribute>
     <seg><xsl:value-of select="source"/></seg>
    </xsl:element>
    <xsl:element name="tuv">
     <xsl:attribute name="xml:lang"><xsl:value-of select="$Trg"/></xsl:attribute>
     <seg><xsl:value-of select="target"/></seg>
    </xsl:element>
   </xsl:element>
 </xsl:template>

</xsl:stylesheet>
